@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -208,22 +208,23 @@ static void class_init (GnomeCmdDirClass *klass)
 
 static void init (GnomeCmdDir *dir)
 {
-    dir->priv = g_new0 (GnomeCmdDirPrivate, 1);
-    dir->voffset = 0;
-    dir->dialog = NULL;
+    // dir->voffset = 0;
+    // dir->dialog = NULL;
     dir->state = DIR_STATE_EMPTY;
 
+    dir->priv = g_new0 (GnomeCmdDirPrivate, 1);
+
+    dir->priv->handle = handle_new (dir);
+    // dir->priv->monitor_handle = NULL;
+    // dir->priv->monitor_users = 0;
+    // dir->priv->files = NULL;
+    dir->priv->file_collection = new GnomeCmdFileCollection;
+
     if (DEBUG_ENABLED ('c'))
     {
         created_dirs_cnt++;
         all_dirs = g_list_append (all_dirs, dir);
     }
-
-    dir->priv->handle = handle_new (dir);
-    dir->priv->monitor_handle = NULL;
-    dir->priv->monitor_users = 0;
-    dir->priv->files = NULL;
-    dir->priv->file_collection = new GnomeCmdFileCollection;
 }
 
 
@@ -358,7 +359,7 @@ GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
     }
     else
     {
-        create_error_dialog (gnome_vfs_result_to_string (res));
+        gnome_cmd_show_message (GTK_WINDOW (main_win), gnome_cmd_path_get_display_path (path), gnome_vfs_result_to_string (res));
         gnome_vfs_file_info_unref (info);
     }
 
