@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -92,7 +92,6 @@ struct GnomeCmdMainWinPrivate
     GtkWidget *mkdir_btn;
     GtkWidget *delete_btn;
     GtkWidget *find_btn;
-    GtkWidget *quit_btn;
 
     GtkWidget *menubar;
     GtkWidget *toolbar;
@@ -132,9 +131,9 @@ gint gnome_cmd_key_snooper(GtkWidget *grab_widget, GdkEventKey *event, GnomeCmdM
     if (event->type!=GDK_KEY_PRESS)
         return FALSE;
 
-    if (!((event->keyval >= GDK_A && event->keyval <= GDK_Z) ||
-            (event->keyval >= GDK_a && event->keyval <= GDK_z) ||
-            (event->keyval == GDK_period)))
+    if (!(event->keyval >= GDK_A && event->keyval <= GDK_Z || event->keyval >= GDK_a && event->keyval <= GDK_z ||
+          event->keyval >= GDK_0 && event->keyval <= GDK_9 ||
+          event->keyval == GDK_period || event->keyval == GDK_question|| event->keyval == GDK_asterisk || event->keyval == GDK_bracketleft))
         return FALSE;
 
     if (!gnome_cmd_data.alt_quick_search)
@@ -410,12 +409,6 @@ static void on_search_clicked (GtkButton *button, GnomeCmdMainWin *mw)
 }
 
 
-static void on_quit_clicked (GtkButton *button, GnomeCmdMainWin *mw)
-{
-    file_exit (NULL);
-}
-
-
 static void create_buttonbar (GnomeCmdMainWin *mw)
 {
     mw->priv->buttonbar_sep = create_separator (FALSE);
@@ -439,8 +432,6 @@ static void create_buttonbar (GnomeCmdMainWin *mw)
     mw->priv->delete_btn = add_buttonbar_button(_("F8 Delete"), main_win, "delete_btn", mw->priv->accel_group, 0);
     gtk_box_pack_start (GTK_BOX (mw->priv->buttonbar), create_separator (TRUE), FALSE, TRUE, 0);
     mw->priv->find_btn = add_buttonbar_button(_("F9 Search"), main_win, "find_btn", mw->priv->accel_group, 0);
-    gtk_box_pack_start (GTK_BOX (mw->priv->buttonbar), create_separator (TRUE), FALSE, TRUE, 0);
-    mw->priv->quit_btn = add_buttonbar_button(_("F10 Quit"), main_win, "quit_btn", mw->priv->accel_group, 0);
 
     gtk_signal_connect (GTK_OBJECT (mw->priv->view_btn), "clicked", GTK_SIGNAL_FUNC (on_view_clicked), mw);
     gtk_signal_connect (GTK_OBJECT (mw->priv->edit_btn), "clicked", GTK_SIGNAL_FUNC (on_edit_clicked), mw);
@@ -449,7 +440,6 @@ static void create_buttonbar (GnomeCmdMainWin *mw)
     gtk_signal_connect (GTK_OBJECT (mw->priv->mkdir_btn), "clicked", GTK_SIGNAL_FUNC (on_mkdir_clicked), mw);
     gtk_signal_connect (GTK_OBJECT (mw->priv->delete_btn), "clicked", GTK_SIGNAL_FUNC (on_delete_clicked), mw);
     gtk_signal_connect (GTK_OBJECT (mw->priv->find_btn), "clicked", GTK_SIGNAL_FUNC (on_search_clicked), mw);
-    gtk_signal_connect (GTK_OBJECT (mw->priv->quit_btn), "clicked", GTK_SIGNAL_FUNC (on_quit_clicked), mw);
 }
 
 
@@ -1109,10 +1099,6 @@ gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event)
                 case GDK_F9:
                     on_search_clicked (NULL, mw);
                     return TRUE;
-
-                case GDK_F10:
-                    on_quit_clicked (NULL, mw);
-                    return TRUE;
             }
 
     if (gnome_cmd_main_win_get_fs (mw, ACTIVE)->key_pressed(event))
