@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,75 +20,75 @@
 #ifndef __GNOME_CMD_TYPES_H__
 #define __GNOME_CMD_TYPES_H__
 
-typedef struct _GnomeCmdBookmarkGroup GnomeCmdBookmarkGroup;
 typedef gchar *GnomeCmdDateFormat;
 
-#include "gnome-cmd-con.h"
-
-G_BEGIN_DECLS
-
-typedef enum
+enum GnomeCmdLayout
 {
     GNOME_CMD_LAYOUT_TEXT,
     GNOME_CMD_LAYOUT_TYPE_ICONS,
     GNOME_CMD_LAYOUT_MIME_ICONS
-} GnomeCmdLayout;
+};
 
 
-typedef enum
+enum GnomeCmdSizeDispMode
 {
     GNOME_CMD_SIZE_DISP_MODE_PLAIN,
     GNOME_CMD_SIZE_DISP_MODE_LOCALE,
     GNOME_CMD_SIZE_DISP_MODE_GROUPED,
     GNOME_CMD_SIZE_DISP_MODE_POWERED
-} GnomeCmdSizeDispMode;
+};
 
 
-typedef enum
+enum GnomeCmdPermDispMode
 {
     GNOME_CMD_PERM_DISP_MODE_TEXT,
-    GNOME_CMD_PERM_DISP_MODE_NUMBER,
-} GnomeCmdPermDispMode;
+    GNOME_CMD_PERM_DISP_MODE_NUMBER
+};
 
 
-typedef enum
+enum GnomeCmdExtDispMode
 {
     GNOME_CMD_EXT_DISP_WITH_FNAME,
     GNOME_CMD_EXT_DISP_STRIPPED,
     GNOME_CMD_EXT_DISP_BOTH
-} GnomeCmdExtDispMode;
+};
 
 
-typedef enum
+enum GnomeCmdColorMode
 {
     GNOME_CMD_COLOR_NONE,
     GNOME_CMD_COLOR_MODERN,
     GNOME_CMD_COLOR_FUSION,
     GNOME_CMD_COLOR_CLASSIC,
     GNOME_CMD_COLOR_DEEP_BLUE,
+    GNOME_CMD_COLOR_CAFEZINHO,
     GNOME_CMD_COLOR_CUSTOM,
     GNOME_CMD_NUM_COLOR_MODES
-} GnomeCmdColorMode;
+};
 
 
-typedef enum  // The (reversed) order of following enums is significant
+enum GnomeCmdConfirmOverwriteMode  // The (reversed) order of following enums is significant
 {
     GNOME_CMD_CONFIRM_OVERWRITE_SKIP_ALL,
     GNOME_CMD_CONFIRM_OVERWRITE_QUERY,
     GNOME_CMD_CONFIRM_OVERWRITE_SILENTLY
-} GnomeCmdConfirmOverwriteMode;
+};
 
 
-typedef struct
+struct GnomeCmdColorTheme
 {
     gboolean respect_theme;
     GdkColor *sel_fg, *sel_bg;
     GdkColor *norm_fg, *norm_bg;
     GdkColor *curs_fg, *curs_bg;
-} GnomeCmdColorTheme;
+    GdkColor *alt_fg, *alt_bg;
+};
 
 
-struct _GnomeCmdBookmarkGroup
+struct GnomeCmdCon;
+
+
+struct GnomeCmdBookmarkGroup
 {
     GList *bookmarks;
     GnomeCmdCon *con;
@@ -95,13 +96,11 @@ struct _GnomeCmdBookmarkGroup
 };
 
 
-typedef struct
+struct GnomeCmdBookmark
 {
     gchar *name;
     gchar *path;
     GnomeCmdBookmarkGroup *group;
-} GnomeCmdBookmark;
-
-G_END_DECLS
+};
 
 #endif // __GNOME_CMD_TYPES_H__
