@@ -24,7 +24,7 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-bookmark-dialog.h"
-#include "gnome-cmd-con.h"
+#include "gnome-cmd-con-home.h"
 #include "gnome-cmd-con-list.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-dir.h"
@@ -222,7 +222,6 @@ void GnomeCmdUserActions::init()
     register_action(GDK_F7, "file.mkdir");
     register_action(GDK_F8, "file.delete");
     // register_action(GDK_F9, "edit.search");     //  do not register F9 here, as edit.search action wouldn't be checked for registration later
-    // register_action(GDK_F10, "file.exit");      //  do not register F10 here, as file.exit action wouldn't be checked for registration later
 
     load("key-bindings");
 
@@ -334,9 +333,6 @@ void GnomeCmdUserActions::init()
 
     unregister(GDK_F9);                                 // unregister F9 if defined in [key-bindings]
     register_action(GDK_F9, "edit.search");             // and overwrite it with edit.search action
-
-    unregister(GDK_F10);                                // unregister F10 if defined in [key-bindings]
-    register_action(GDK_F10, "file.exit");              // and overwrite it with file.exit action
  }
 
 
@@ -351,7 +347,6 @@ void GnomeCmdUserActions::shutdown()
     unregister(GDK_F7);
     unregister(GDK_F8);
     unregister(GDK_F9);
-    unregister(GDK_F10);
 
     write("key-bindings");
 
@@ -1106,25 +1101,37 @@ void command_open_nautilus_in_cwd (GtkMenuItem *menuitem, gpointer not_used)
 
 void command_root_mode (GtkMenuItem *menuitem, gpointer not_used)
 {
-    char *su;
+    char *su = NULL;
+    gboolean need_c = FALSE;
 
-    su = g_find_program_in_path ("gksu");
-    if  (!su)
-        su = g_find_program_in_path ("kdesu");
-    if  (!su)
-        su = g_find_program_in_path ("beesu");
+    if ((su = g_find_program_in_path ("xdg-su")))
+        goto with_c_param;
+    if ((su = g_find_program_in_path ("gksu")))
+        goto without_c_param;
+    if ((su = g_find_program_in_path ("gnomesu")))
+        goto with_c_param;
+    if ((su = g_find_program_in_path ("beesu")))
+        goto without_c_param;
+    if ((su = g_find_program_in_path ("kdesu")))
+        goto without_c_param;
 
-    if  (!su)
-    {
-        gnome_cmd_show_message (NULL, _("gksu, kdesu or beesu is not found."));
-        return ;
-    }
+    gnome_cmd_show_message (NULL, _("xdg-su, gksu, gnomesu, kdesu or beesu is not found."));
+    return;
 
-    char *argv[3];
+  with_c_param:
 
-    argv[0] = su;
-    argv[1] = g_get_prgname ();
-    argv[2] = NULL;
+    need_c = TRUE;
+
+  without_c_param:
+
+    char *argv[4];
+    int i = 0;
+
+    argv[i++] = su;
+    argv[i++] = g_get_prgname ();
+    if (need_c)
+        argv[i++] = "-c";
+    argv[i++] = NULL;
 
     GError *error = NULL;
 
@@ -1430,7 +1437,7 @@ void connections_close_current (GtkMenuItem *menuitem, gpointer not_used)
 {
     GnomeCmdCon *con = get_fs (ACTIVE)->get_connection();
 
-    if (!gnome_cmd_con_is_local (con))
+    if (!GNOME_CMD_IS_CON_HOME (con))
         connections_close (menuitem, con);
 }
 
